/*
 * Copyright (c) 2007 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: MyLEADUtil.java,v 1.1 2007/07/06 20:39:59 sshirasu Exp $
 */
package edu.indiana.extreme.xbaya.util;

import java.io.File;
import java.io.IOException;

import org.globus.myproxy.MyProxyException;
import org.gpel.client.security.GpelUserX509Credential;
import org.ietf.jgss.GSSCredential;
import org.xmlpull.infoset.XmlElement;

import xsul5.MLogger;
import edu.indiana.extreme.xbaya.XBayaConfiguration;
import edu.indiana.extreme.xbaya.component.ComponentException;
import edu.indiana.extreme.xbaya.gpel.GPELClient;
import edu.indiana.extreme.xbaya.gpel.GPELException;
import edu.indiana.extreme.xbaya.graph.GraphException;
import edu.indiana.extreme.xbaya.mylead.MyLead;
import edu.indiana.extreme.xbaya.mylead.MyLeadConfiguration;
import edu.indiana.extreme.xbaya.mylead.MyLeadException;
import edu.indiana.extreme.xbaya.myproxy.MyProxyClient;
import edu.indiana.extreme.xbaya.wf.Workflow;

/**
 * @author Satoshi Shirasuna
 */
public class MyLEADUtil {

    private final static MLogger logger = MLogger.getLogger();

    /**
     * @param configuration
     *            myProxyServer, myProxyPort, myProxyUsername,
     *            myProxyPassphrase, myProxyLifetime, gpelEngineURL,
     *            myLEADAgentURL, myLEADAgentUser, and myLEADAgentProject are
     *            used.
     * @param workflowFile
     *            The workflow file to deploy in File.
     * @param certKeyFile
     *            The file pass in String.
     * @param trustedCertsFile
     *            The file pass in String.
     * @return the myLEAD resouce ID for the deployed workflow.
     * @throws ComponentException
     * @throws GraphException
     * @throws MyLeadException
     * @throws GPELException
     * @throws MyProxyException
     * @throws IOException
     */
    public String deploy(XBayaConfiguration configuration, File workflowFile,
            String certKeyFile, String trustedCertsFile)
            throws ComponentException, GraphException, MyLeadException,
            GPELException, MyProxyException, IOException {

        // Load a workflow from a file
        logger.info("Loading a workflow file.");
        XmlElement workflowXML = XMLUtil.loadXML(workflowFile);
        Workflow workflow = new Workflow(workflowXML);

        // Get MyProxy
        logger.info("Loading myProxy.");
        MyProxyClient myProxyClient = new MyProxyClient(configuration
                .getMyProxyServer(), configuration.getMyProxyPort(),
                configuration.getMyProxyUsername(), configuration
                        .getMyProxyPassphrase(), configuration
                        .getMyProxyLifetime());
        myProxyClient.load();
        GSSCredential proxy = myProxyClient.getProxy();

        // Deploy to GPEL
        logger.info("Deploying the workflow to the GPEL Engine.");
        GpelUserX509Credential gpelUserCredential = new GpelUserX509Credential(
                certKeyFile, trustedCertsFile);
        GPELClient gpelClient = new GPELClient(
                configuration.getGPELEngineURL(), gpelUserCredential);
        gpelClient.setEngineURL(configuration.getGPELEngineURL());
        gpelClient.createScriptAndDeploy(workflow, false);

        logger.info("Deploying the workflow to myLEAD.");
        MyLeadConfiguration myleadConfig = new MyLeadConfiguration(
                configuration.getMyLeadAgentURL(), configuration
                        .getMyLeadUser(), configuration.getMyLeadProject());
        MyLead myLead = new MyLead(myleadConfig, proxy);
        String resourceID = myLead.save(workflow, false);

        logger.info("Everything is done succeessfully.");

        return resourceID;
    }
}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2007 The Trustees of Indiana University. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
